@@ -95,3 +95,35 @@ class Setup(ListoAPI):
                 ```
         """
         return self.make_request(method="POST", path="/customers/prefs", data=kwargs).json()
+
+    def pause_sat_sync(self, rfc_id):
+        """  Pausar descarga automática
+            Parameters:
+                rfc_id (str|int)
+            Returns:
+                json: {"status": "ok"}
+            Example:
+                ```python
+                from listoapi import ListoApi
+                api = ListoApi("<api_key>")
+                api.Setup.pause_sat_sync(rfc_id=3)
+                # returns: {"status": "ok"}
+                ```
+        """
+        return self.make_request(method="POST", path="/customers/rfcs/%s/pause_sat_sync" % rfc_id).json()
+
+    def resume_sat_sync(self, rfc_id):
+        """  Reanudar descarga automática
+            Parameters:
+                rfc_id (str|int)
+            Returns:
+                json: {"status": "ok"}
+            Example:
+                ```python
+                from listoapi import ListoApi
+                api = ListoApi("<api_key>")
+                api.Setup.pause_sat_sync(rfc_id=3)
+                # returns: {"status": "ok"}
+                ```
+        """
+        return self.make_request(method="POST", path="/customers/rfcs/%s/resume_sat_sync" % rfc_id).json()
